/* MainEngineButton
   A demo of sending commands using ArduinosInSpace. Here we're using
   a big red button to control the main engine. Hold the button down
   to burn.

   Hardware:
   - A momentary push button. This should be connected to pin 2,
     following the Arduino example given at
     https://www.arduino.cc/en/Tutorial/Button with a pull-down
     resistor.
   Software:
   - Install the Bounce2 library. Either install it using the
     Arduino Library Manager, or from
     https://github.com/thomasfredericks/Bounce2
*/
#include <Bounce2.h>
#include <ArduinosInSpace.h>

// The pin our button is connected to
const int engineButtonPin = 2;
// A Bounce2 instance to handle our push button
Bounce engineButton = Bounce();

// Create an ObjectsInSpace object. The arguments are
// the serial device to use (use "Serial" if unsure),
// and the number of request channels. We're not
// requesting any data, so that number is 0
ObjectsInSpace OIS(Serial, 0);

void setup() {
  // Set up Bounce2 to handle our input.
  pinMode(engineButtonPin, INPUT);
  engineButton.attach(engineButtonPin);
  engineButton.interval(5);

  // Open the serial connection, and tell ArduinosInSpace
  // to perform handshaking with the game
  Serial.begin(9600);
  OIS.begin();

  // Synchronise with the game. Here we tell it that
  // we'll be sending main engine start and stop commands.
  OIS.registerCommand(BURN_MAIN_ENGINE);
  OIS.registerCommand(STOP_MAIN_ENGINE);

  // Complete synchronisation and activate the game link.
  OIS.activate();
}

void loop() {
  // Update button state
  engineButton.update();
  if (engineButton.rose()) {
    // Button has been pressed, so burn engine
    OIS.sendCommand(BURN_MAIN_ENGINE);
  } else if (engineButton.fell()) {
    // Button has been released, so stop burn
    OIS.sendCommand(STOP_MAIN_ENGINE);
  }

  // The update() method checks for and processes serial data.
  OIS.update();
}
